# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ProtectAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_password': 'str',
        'owner_password': 'str',
        'unlock': 'bool',
        'permissions': 'list[str]'
    }

    attribute_map = {
        'user_password': 'userPassword',
        'owner_password': 'ownerPassword',
        'unlock': 'unlock',
        'permissions': 'permissions'
    }

    def __init__(self, user_password=None, owner_password=None, unlock=None, permissions=None):  # noqa: E501
        """ProtectAction - a model defined in Swagger"""  # noqa: E501

        self._user_password = None
        self._owner_password = None
        self._unlock = None
        self._permissions = None
        self.discriminator = None

        if user_password is not None:
            self.user_password = user_password
        if owner_password is not None:
            self.owner_password = owner_password
        if unlock is not None:
            self.unlock = unlock
        if permissions is not None:
            self.permissions = permissions

    @property
    def user_password(self):
        """Gets the user_password of this ProtectAction.  # noqa: E501


        :return: The user_password of this ProtectAction.  # noqa: E501
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """Sets the user_password of this ProtectAction.


        :param user_password: The user_password of this ProtectAction.  # noqa: E501
        :type: str
        """

        self._user_password = user_password

    @property
    def owner_password(self):
        """Gets the owner_password of this ProtectAction.  # noqa: E501


        :return: The owner_password of this ProtectAction.  # noqa: E501
        :rtype: str
        """
        return self._owner_password

    @owner_password.setter
    def owner_password(self, owner_password):
        """Sets the owner_password of this ProtectAction.


        :param owner_password: The owner_password of this ProtectAction.  # noqa: E501
        :type: str
        """

        self._owner_password = owner_password

    @property
    def unlock(self):
        """Gets the unlock of this ProtectAction.  # noqa: E501


        :return: The unlock of this ProtectAction.  # noqa: E501
        :rtype: bool
        """
        return self._unlock

    @unlock.setter
    def unlock(self, unlock):
        """Sets the unlock of this ProtectAction.


        :param unlock: The unlock of this ProtectAction.  # noqa: E501
        :type: bool
        """

        self._unlock = unlock

    @property
    def permissions(self):
        """Gets the permissions of this ProtectAction.  # noqa: E501


        :return: The permissions of this ProtectAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this ProtectAction.


        :param permissions: The permissions of this ProtectAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["all", "none", "copy", "annotate", "fillForms", "supportDisabilities", "assemble", "digitalPrint", "print", "modify"]  # noqa: E501
        if not set(permissions).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `permissions` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(permissions) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProtectAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtectAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_metadata import DocMetadata  # noqa: F401,E501


class CheckAvailabilityRes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'trace_id': 'str',
        'in_doc_metadata': 'DocMetadata',
        'status': 'bool'
    }

    attribute_map = {
        'trace_id': 'traceId',
        'in_doc_metadata': 'inDocMetadata',
        'status': 'Status'
    }

    def __init__(self, trace_id=None, in_doc_metadata=None, status=None):  # noqa: E501
        """CheckAvailabilityRes - a model defined in Swagger"""  # noqa: E501

        self._trace_id = None
        self._in_doc_metadata = None
        self._status = None
        self.discriminator = None

        if trace_id is not None:
            self.trace_id = trace_id
        if in_doc_metadata is not None:
            self.in_doc_metadata = in_doc_metadata
        if status is not None:
            self.status = status

    @property
    def trace_id(self):
        """Gets the trace_id of this CheckAvailabilityRes.  # noqa: E501


        :return: The trace_id of this CheckAvailabilityRes.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this CheckAvailabilityRes.


        :param trace_id: The trace_id of this CheckAvailabilityRes.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def in_doc_metadata(self):
        """Gets the in_doc_metadata of this CheckAvailabilityRes.  # noqa: E501


        :return: The in_doc_metadata of this CheckAvailabilityRes.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._in_doc_metadata

    @in_doc_metadata.setter
    def in_doc_metadata(self, in_doc_metadata):
        """Sets the in_doc_metadata of this CheckAvailabilityRes.


        :param in_doc_metadata: The in_doc_metadata of this CheckAvailabilityRes.  # noqa: E501
        :type: DocMetadata
        """

        self._in_doc_metadata = in_doc_metadata

    @property
    def status(self):
        """Gets the status of this CheckAvailabilityRes.  # noqa: E501


        :return: The status of this CheckAvailabilityRes.  # noqa: E501
        :rtype: bool
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckAvailabilityRes.


        :param status: The status of this CheckAvailabilityRes.  # noqa: E501
        :type: bool
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CheckAvailabilityRes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckAvailabilityRes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExtractResourcesAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'extract_fonts': 'bool',
        'extract_images': 'bool',
        'list_fonts': 'bool',
        'list_images': 'bool',
        'outlines': 'bool',
        'xmp_metadata': 'bool'
    }

    attribute_map = {
        'extract_fonts': 'extractFonts',
        'extract_images': 'extractImages',
        'list_fonts': 'listFonts',
        'list_images': 'listImages',
        'outlines': 'outlines',
        'xmp_metadata': 'xmpMetadata'
    }

    def __init__(self, extract_fonts=None, extract_images=None, list_fonts=None, list_images=None, outlines=None, xmp_metadata=None):  # noqa: E501
        """ExtractResourcesAction - a model defined in Swagger"""  # noqa: E501

        self._extract_fonts = None
        self._extract_images = None
        self._list_fonts = None
        self._list_images = None
        self._outlines = None
        self._xmp_metadata = None
        self.discriminator = None

        if extract_fonts is not None:
            self.extract_fonts = extract_fonts
        if extract_images is not None:
            self.extract_images = extract_images
        if list_fonts is not None:
            self.list_fonts = list_fonts
        if list_images is not None:
            self.list_images = list_images
        if outlines is not None:
            self.outlines = outlines
        if xmp_metadata is not None:
            self.xmp_metadata = xmp_metadata

    @property
    def extract_fonts(self):
        """Gets the extract_fonts of this ExtractResourcesAction.  # noqa: E501

         Get or set whether to extract embedded fonts. Depending on the font type, the extracted font has one of the   following three formats: fnt‹objno›.ttf or fnt‹objno›.pfb or fnt‹objno›.cff, where ‹objno› is the  number of the PDF object of the font.   {default:  false}  # noqa: E501

        :return: The extract_fonts of this ExtractResourcesAction.  # noqa: E501
        :rtype: bool
        """
        return self._extract_fonts

    @extract_fonts.setter
    def extract_fonts(self, extract_fonts):
        """Sets the extract_fonts of this ExtractResourcesAction.

         Get or set whether to extract embedded fonts. Depending on the font type, the extracted font has one of the   following three formats: fnt‹objno›.ttf or fnt‹objno›.pfb or fnt‹objno›.cff, where ‹objno› is the  number of the PDF object of the font.   {default:  false}  # noqa: E501

        :param extract_fonts: The extract_fonts of this ExtractResourcesAction.  # noqa: E501
        :type: bool
        """

        self._extract_fonts = extract_fonts

    @property
    def extract_images(self):
        """Gets the extract_images of this ExtractResourcesAction.  # noqa: E501

        Get or set whether to extract images.Depending on the compression, the extracted image has one of the following  formats: img‹objno›.tif or img‹objno›.jpg, where objno is the number of the PDF object of the image.  {default:  false}  # noqa: E501

        :return: The extract_images of this ExtractResourcesAction.  # noqa: E501
        :rtype: bool
        """
        return self._extract_images

    @extract_images.setter
    def extract_images(self, extract_images):
        """Sets the extract_images of this ExtractResourcesAction.

        Get or set whether to extract images.Depending on the compression, the extracted image has one of the following  formats: img‹objno›.tif or img‹objno›.jpg, where objno is the number of the PDF object of the image.  {default:  false}  # noqa: E501

        :param extract_images: The extract_images of this ExtractResourcesAction.  # noqa: E501
        :type: bool
        """

        self._extract_images = extract_images

    @property
    def list_fonts(self):
        """Gets the list_fonts of this ExtractResourcesAction.  # noqa: E501

        List all fonts included in the document and write them as a list to a text file  {default:  false}  # noqa: E501

        :return: The list_fonts of this ExtractResourcesAction.  # noqa: E501
        :rtype: bool
        """
        return self._list_fonts

    @list_fonts.setter
    def list_fonts(self, list_fonts):
        """Sets the list_fonts of this ExtractResourcesAction.

        List all fonts included in the document and write them as a list to a text file  {default:  false}  # noqa: E501

        :param list_fonts: The list_fonts of this ExtractResourcesAction.  # noqa: E501
        :type: bool
        """

        self._list_fonts = list_fonts

    @property
    def list_images(self):
        """Gets the list_images of this ExtractResourcesAction.  # noqa: E501

        List all images included in the document and write them as a list to a text file.  {default:  false}  # noqa: E501

        :return: The list_images of this ExtractResourcesAction.  # noqa: E501
        :rtype: bool
        """
        return self._list_images

    @list_images.setter
    def list_images(self, list_images):
        """Sets the list_images of this ExtractResourcesAction.

        List all images included in the document and write them as a list to a text file.  {default:  false}  # noqa: E501

        :param list_images: The list_images of this ExtractResourcesAction.  # noqa: E501
        :type: bool
        """

        self._list_images = list_images

    @property
    def outlines(self):
        """Gets the outlines of this ExtractResourcesAction.  # noqa: E501


        :return: The outlines of this ExtractResourcesAction.  # noqa: E501
        :rtype: bool
        """
        return self._outlines

    @outlines.setter
    def outlines(self, outlines):
        """Sets the outlines of this ExtractResourcesAction.


        :param outlines: The outlines of this ExtractResourcesAction.  # noqa: E501
        :type: bool
        """

        self._outlines = outlines

    @property
    def xmp_metadata(self):
        """Gets the xmp_metadata of this ExtractResourcesAction.  # noqa: E501


        :return: The xmp_metadata of this ExtractResourcesAction.  # noqa: E501
        :rtype: bool
        """
        return self._xmp_metadata

    @xmp_metadata.setter
    def xmp_metadata(self, xmp_metadata):
        """Sets the xmp_metadata of this ExtractResourcesAction.


        :param xmp_metadata: The xmp_metadata of this ExtractResourcesAction.  # noqa: E501
        :type: bool
        """

        self._xmp_metadata = xmp_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExtractResourcesAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractResourcesAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.pdf_validation_event import PdfValidationEvent  # noqa: F401,E501


class PdfValidation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'validations': 'list[PdfValidationEvent]',
        'conformance_codes': 'list[str]',
        'error_code': 'str',
        'error_message': 'str'
    }

    attribute_map = {
        'validations': 'validations',
        'conformance_codes': 'conformanceCodes',
        'error_code': 'errorCode',
        'error_message': 'errorMessage'
    }

    def __init__(self, validations=None, conformance_codes=None, error_code=None, error_message=None):  # noqa: E501
        """PdfValidation - a model defined in Swagger"""  # noqa: E501

        self._validations = None
        self._conformance_codes = None
        self._error_code = None
        self._error_message = None
        self.discriminator = None

        if validations is not None:
            self.validations = validations
        if conformance_codes is not None:
            self.conformance_codes = conformance_codes
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message

    @property
    def validations(self):
        """Gets the validations of this PdfValidation.  # noqa: E501


        :return: The validations of this PdfValidation.  # noqa: E501
        :rtype: list[PdfValidationEvent]
        """
        return self._validations

    @validations.setter
    def validations(self, validations):
        """Sets the validations of this PdfValidation.


        :param validations: The validations of this PdfValidation.  # noqa: E501
        :type: list[PdfValidationEvent]
        """

        self._validations = validations

    @property
    def conformance_codes(self):
        """Gets the conformance_codes of this PdfValidation.  # noqa: E501


        :return: The conformance_codes of this PdfValidation.  # noqa: E501
        :rtype: list[str]
        """
        return self._conformance_codes

    @conformance_codes.setter
    def conformance_codes(self, conformance_codes):
        """Sets the conformance_codes of this PdfValidation.


        :param conformance_codes: The conformance_codes of this PdfValidation.  # noqa: E501
        :type: list[str]
        """

        self._conformance_codes = conformance_codes

    @property
    def error_code(self):
        """Gets the error_code of this PdfValidation.  # noqa: E501


        :return: The error_code of this PdfValidation.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this PdfValidation.


        :param error_code: The error_code of this PdfValidation.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this PdfValidation.  # noqa: E501


        :return: The error_message of this PdfValidation.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this PdfValidation.


        :param error_message: The error_message of this PdfValidation.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfValidation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfValidation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import jprops

from pdf4me.helper.custom_http import CustomHttp
from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException

DEFAULT_CONFIG_PROPERTIES = '../config.properties'


class Pdf4meClient(object):

    def __init__(self, token=None, apiurl=None, path_to_config_file=DEFAULT_CONFIG_PROPERTIES):

        # in case either token is not provided, load them from the property file
        if token is None:

            # load token from property file
            try:
                with open(path_to_config_file) as fp:
                    props = list(jprops.iter_properties(fp))

                    prop_token = None
                    prop_apiurl = None

                    # check whether token and apiurl exist
                    for key, value in props:
                        if key == 'token':
                            prop_token = value
                        if key == 'apiurl':
                            prop_apiurl = value

                    if prop_token is None:
                        raise Pdf4meClientException(
                            'Please store the token in the  ' + path_to_config_file + 'file or provide your token in the Pdf4meClient constructor.')
            except IOError:
                raise Pdf4meClientException(
                    'The config.properties file is not stored at \'' + path_to_config_file + '\'. Please initialize the Pdf4meClient object with the correct path to your conifg.properties file. Or else provide your token in the Pdf4meClient constructor.')

            self.custom_http = CustomHttp(prop_token, prop_apiurl)
        else:
            self.custom_http = CustomHttp(token, apiurl)



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.color import Color  # noqa: F401,E501
from pdf4me.model.rotate_config import RotateConfig  # noqa: F401,E501
from pdf4me.model.transform import Transform  # noqa: F401,E501
from pdf4me.model.translate import Translate  # noqa: F401,E501


class Text(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'bool',
        'size': 'int',
        'font': 'str',
        'color': 'Color',
        'font_encoding': 'str',
        'value': 'str',
        'mode': 'str',
        'rotate': 'RotateConfig',
        'translate': 'Translate',
        'transform': 'Transform'
    }

    attribute_map = {
        'format': 'format',
        'size': 'size',
        'font': 'font',
        'color': 'color',
        'font_encoding': 'fontEncoding',
        'value': 'value',
        'mode': 'mode',
        'rotate': 'rotate',
        'translate': 'translate',
        'transform': 'transform'
    }

    def __init__(self, format=None, size=None, font=None, color=None, font_encoding=None, value=None, mode=None, rotate=None, translate=None, transform=None):  # noqa: E501
        """Text - a model defined in Swagger"""  # noqa: E501

        self._format = None
        self._size = None
        self._font = None
        self._color = None
        self._font_encoding = None
        self._value = None
        self._mode = None
        self._rotate = None
        self._translate = None
        self._transform = None
        self.discriminator = None

        if format is not None:
            self.format = format
        if size is not None:
            self.size = size
        if font is not None:
            self.font = font
        if color is not None:
            self.color = color
        if font_encoding is not None:
            self.font_encoding = font_encoding
        self.value = value
        if mode is not None:
            self.mode = mode
        if rotate is not None:
            self.rotate = rotate
        if translate is not None:
            self.translate = translate
        if transform is not None:
            self.transform = transform

    @property
    def format(self):
        """Gets the format of this Text.  # noqa: E501


        :return: The format of this Text.  # noqa: E501
        :rtype: bool
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Text.


        :param format: The format of this Text.  # noqa: E501
        :type: bool
        """

        self._format = format

    @property
    def size(self):
        """Gets the size of this Text.  # noqa: E501

        The font size in points, e.g. 12. If set to 0, the size is chosen such that text fits stamp size (not allowed if operator is within transformation operator).  # noqa: E501

        :return: The size of this Text.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Text.

        The font size in points, e.g. 12. If set to 0, the size is chosen such that text fits stamp size (not allowed if operator is within transformation operator).  # noqa: E501

        :param size: The size of this Text.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def font(self):
        """Gets the font of this Text.  # noqa: E501


        :return: The font of this Text.  # noqa: E501
        :rtype: str
        """
        return self._font

    @font.setter
    def font(self, font):
        """Sets the font of this Text.


        :param font: The font of this Text.  # noqa: E501
        :type: str
        """

        self._font = font

    @property
    def color(self):
        """Gets the color of this Text.  # noqa: E501


        :return: The color of this Text.  # noqa: E501
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this Text.


        :param color: The color of this Text.  # noqa: E501
        :type: Color
        """

        self._color = color

    @property
    def font_encoding(self):
        """Gets the font_encoding of this Text.  # noqa: E501


        :return: The font_encoding of this Text.  # noqa: E501
        :rtype: str
        """
        return self._font_encoding

    @font_encoding.setter
    def font_encoding(self, font_encoding):
        """Sets the font_encoding of this Text.


        :param font_encoding: The font_encoding of this Text.  # noqa: E501
        :type: str
        """
        allowed_values = ["unicode", "winAnsi"]  # noqa: E501
        if font_encoding not in allowed_values:
            raise ValueError(
                "Invalid value for `font_encoding` ({0}), must be one of {1}"  # noqa: E501
                .format(font_encoding, allowed_values)
            )

        self._font_encoding = font_encoding

    @property
    def value(self):
        """Gets the value of this Text.  # noqa: E501


        :return: The value of this Text.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Text.


        :param value: The value of this Text.  # noqa: E501
        :type: str
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def mode(self):
        """Gets the mode of this Text.  # noqa: E501


        :return: The mode of this Text.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this Text.


        :param mode: The mode of this Text.  # noqa: E501
        :type: str
        """
        allowed_values = ["fill", "stroke"]  # noqa: E501
        if mode not in allowed_values:
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}"  # noqa: E501
                .format(mode, allowed_values)
            )

        self._mode = mode

    @property
    def rotate(self):
        """Gets the rotate of this Text.  # noqa: E501


        :return: The rotate of this Text.  # noqa: E501
        :rtype: RotateConfig
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """Sets the rotate of this Text.


        :param rotate: The rotate of this Text.  # noqa: E501
        :type: RotateConfig
        """

        self._rotate = rotate

    @property
    def translate(self):
        """Gets the translate of this Text.  # noqa: E501


        :return: The translate of this Text.  # noqa: E501
        :rtype: Translate
        """
        return self._translate

    @translate.setter
    def translate(self, translate):
        """Sets the translate of this Text.


        :param translate: The translate of this Text.  # noqa: E501
        :type: Translate
        """

        self._translate = translate

    @property
    def transform(self):
        """Gets the transform of this Text.  # noqa: E501


        :return: The transform of this Text.  # noqa: E501
        :rtype: Transform
        """
        return self._transform

    @transform.setter
    def transform(self, transform):
        """Sets the transform of this Text.


        :param transform: The transform of this Text.  # noqa: E501
        :type: Transform
        """

        self._transform = transform

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Text, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Text):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ConvertToPdfAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pdf_conformance': 'str',
        'conversion_mode': 'str'
    }

    attribute_map = {
        'pdf_conformance': 'pdfConformance',
        'conversion_mode': 'conversionMode'
    }

    def __init__(self, pdf_conformance=None, conversion_mode=None):  # noqa: E501
        """ConvertToPdfAction - a model defined in Swagger"""  # noqa: E501

        self._pdf_conformance = None
        self._conversion_mode = None
        self.discriminator = None

        if pdf_conformance is not None:
            self.pdf_conformance = pdf_conformance
        if conversion_mode is not None:
            self.conversion_mode = conversion_mode

    @property
    def pdf_conformance(self):
        """Gets the pdf_conformance of this ConvertToPdfAction.  # noqa: E501


        :return: The pdf_conformance of this ConvertToPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._pdf_conformance

    @pdf_conformance.setter
    def pdf_conformance(self, pdf_conformance):
        """Sets the pdf_conformance of this ConvertToPdfAction.


        :param pdf_conformance: The pdf_conformance of this ConvertToPdfAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["pdf17", "pdfA1", "pdfA2", "pdfA3"]  # noqa: E501
        if pdf_conformance not in allowed_values:
            raise ValueError(
                "Invalid value for `pdf_conformance` ({0}), must be one of {1}"  # noqa: E501
                .format(pdf_conformance, allowed_values)
            )

        self._pdf_conformance = pdf_conformance

    @property
    def conversion_mode(self):
        """Gets the conversion_mode of this ConvertToPdfAction.  # noqa: E501


        :return: The conversion_mode of this ConvertToPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._conversion_mode

    @conversion_mode.setter
    def conversion_mode(self, conversion_mode):
        """Sets the conversion_mode of this ConvertToPdfAction.


        :param conversion_mode: The conversion_mode of this ConvertToPdfAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["fast", "detailed"]  # noqa: E501
        if conversion_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `conversion_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(conversion_mode, allowed_values)
            )

        self._conversion_mode = conversion_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConvertToPdfAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvertToPdfAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import ConvertToPdf


class ConvertClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def convert_to_pdf(self, convert_to_pdf):
        """The predefined convert_to_pdf is carried out.

        :param convert_to_pdf: PDF conversion configuration
        :type convert_to_pdf: ConvertToPdf
        :return: ConvertToPdfRes, contains generated PDF
        """

        # check convert_to_pdf validity
        self.__check_convert_to_pdf_object_validity(convert_to_pdf)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=convert_to_pdf,
                                                                   controller='Convert/ConvertToPdf')

        return res

    def convert_file_to_pdf(self, file_name, file):
        """The provided Non-PDF file gets converted to a PDF.

        :param file_name: the name of the provided file (including the file extension)
        :type file_name: str
        :param file: to be converted to PDF
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting PDF file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('fileName', file_name)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Convert/ConvertFileToPdf')

    def __check_convert_to_pdf_object_validity(self, convert_to_pdf):
        """Checks whether the convert_to_pdf object contains the essential information to be
                processed by the server."""

        if convert_to_pdf is None:
            raise Pdf4meClientException('The convert_to_pdf parameter cannot be None.')
        elif convert_to_pdf.document is None or convert_to_pdf.document.doc_data is None:
            raise Pdf4meClientException('The convert_to_pdf document cannot be None.')
        elif convert_to_pdf.document.name is None:
            raise Pdf4meClientException(
                'The name field of convertToPdf\'s document cannot be None (name must incl. file extension).')
        elif convert_to_pdf.convert_to_pdf_action is None:
            raise Pdf4meClientException('The convert_to_pdf_action cannot be None.')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.rectangle import Rectangle  # noqa: F401,E501
from pdf4me.model.rotate_config import RotateConfig  # noqa: F401,E501
from pdf4me.model.transform import Transform  # noqa: F401,E501
from pdf4me.model.translate import Translate  # noqa: F401,E501


class Image(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rectangle': 'Rectangle',
        'image_data': 'str',
        'image_type': 'str',
        'file_name': 'str',
        'compression': 'str',
        'rotate': 'RotateConfig',
        'translate': 'Translate',
        'transform': 'Transform'
    }

    attribute_map = {
        'rectangle': 'rectangle',
        'image_data': 'imageData',
        'image_type': 'imageType',
        'file_name': 'fileName',
        'compression': 'compression',
        'rotate': 'rotate',
        'translate': 'translate',
        'transform': 'transform'
    }

    def __init__(self, rectangle=None, image_data=None, image_type=None, file_name=None, compression=None, rotate=None, translate=None, transform=None):  # noqa: E501
        """Image - a model defined in Swagger"""  # noqa: E501

        self._rectangle = None
        self._image_data = None
        self._image_type = None
        self._file_name = None
        self._compression = None
        self._rotate = None
        self._translate = None
        self._transform = None
        self.discriminator = None

        if rectangle is not None:
            self.rectangle = rectangle
        if image_data is not None:
            self.image_data = image_data
        if image_type is not None:
            self.image_type = image_type
        if file_name is not None:
            self.file_name = file_name
        if compression is not None:
            self.compression = compression
        if rotate is not None:
            self.rotate = rotate
        if translate is not None:
            self.translate = translate
        if transform is not None:
            self.transform = transform

    @property
    def rectangle(self):
        """Gets the rectangle of this Image.  # noqa: E501


        :return: The rectangle of this Image.  # noqa: E501
        :rtype: Rectangle
        """
        return self._rectangle

    @rectangle.setter
    def rectangle(self, rectangle):
        """Sets the rectangle of this Image.


        :param rectangle: The rectangle of this Image.  # noqa: E501
        :type: Rectangle
        """

        self._rectangle = rectangle

    @property
    def image_data(self):
        """Gets the image_data of this Image.  # noqa: E501


        :return: The image_data of this Image.  # noqa: E501
        :rtype: str
        """
        return self._image_data

    @image_data.setter
    def image_data(self, image_data):
        """Sets the image_data of this Image.


        :param image_data: The image_data of this Image.  # noqa: E501
        :type: str
        """
        if image_data is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', image_data):  # noqa: E501
            raise ValueError(r"Invalid value for `image_data`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._image_data = image_data

    @property
    def image_type(self):
        """Gets the image_type of this Image.  # noqa: E501


        :return: The image_type of this Image.  # noqa: E501
        :rtype: str
        """
        return self._image_type

    @image_type.setter
    def image_type(self, image_type):
        """Sets the image_type of this Image.


        :param image_type: The image_type of this Image.  # noqa: E501
        :type: str
        """

        self._image_type = image_type

    @property
    def file_name(self):
        """Gets the file_name of this Image.  # noqa: E501


        :return: The file_name of this Image.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Image.


        :param file_name: The file_name of this Image.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def compression(self):
        """Gets the compression of this Image.  # noqa: E501


        :return: The compression of this Image.  # noqa: E501
        :rtype: str
        """
        return self._compression

    @compression.setter
    def compression(self, compression):
        """Sets the compression of this Image.


        :param compression: The compression of this Image.  # noqa: E501
        :type: str
        """
        allowed_values = ["cCITTFax", "flate", "dCT"]  # noqa: E501
        if compression not in allowed_values:
            raise ValueError(
                "Invalid value for `compression` ({0}), must be one of {1}"  # noqa: E501
                .format(compression, allowed_values)
            )

        self._compression = compression

    @property
    def rotate(self):
        """Gets the rotate of this Image.  # noqa: E501


        :return: The rotate of this Image.  # noqa: E501
        :rtype: RotateConfig
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """Sets the rotate of this Image.


        :param rotate: The rotate of this Image.  # noqa: E501
        :type: RotateConfig
        """

        self._rotate = rotate

    @property
    def translate(self):
        """Gets the translate of this Image.  # noqa: E501


        :return: The translate of this Image.  # noqa: E501
        :rtype: Translate
        """
        return self._translate

    @translate.setter
    def translate(self, translate):
        """Sets the translate of this Image.


        :param translate: The translate of this Image.  # noqa: E501
        :type: Translate
        """

        self._translate = translate

    @property
    def transform(self):
        """Gets the transform of this Image.  # noqa: E501


        :return: The transform of this Image.  # noqa: E501
        :rtype: Transform
        """
        return self._transform

    @transform.setter
    def transform(self, transform):
        """Sets the transform of this Image.


        :param transform: The transform of this Image.  # noqa: E501
        :type: Transform
        """

        self._transform = transform

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Image, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Image):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import base64


class FileReader(object):

    def get_file_data(self, path):
        """Returns the content of the file in base64.

        :param path: path to file
        :type path: str
        :return: base64
        """

        with open(path, 'rb') as file:
            pdf_base64 = file.read()

        data = base64.b64encode(pdf_base64)
        data = data.decode('utf-8')

        return data

    def get_file_handler(self, path):
        """Returns the file handler of the provided file.

        :param path: path to file
        :type path: str
        :return: the file handler of the provided file
        """
        return open(path, 'rb')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.convert_to_pdf_action import ConvertToPdfAction  # noqa: F401,E501
from pdf4me.model.document import Document  # noqa: F401,E501


class ConvertToPdf(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document': 'Document',
        'convert_to_pdf_action': 'ConvertToPdfAction',
        'job_id': 'str',
        'job_id_ext': 'str',
        'integrations': 'list[str]'
    }

    attribute_map = {
        'document': 'document',
        'convert_to_pdf_action': 'convertToPdfAction',
        'job_id': 'jobId',
        'job_id_ext': 'jobIdExt',
        'integrations': 'integrations'
    }

    def __init__(self, document=None, convert_to_pdf_action=None, job_id=None, job_id_ext=None, integrations=None):  # noqa: E501
        """ConvertToPdf - a model defined in Swagger"""  # noqa: E501

        self._document = None
        self._convert_to_pdf_action = None
        self._job_id = None
        self._job_id_ext = None
        self._integrations = None
        self.discriminator = None

        self.document = document
        if convert_to_pdf_action is not None:
            self.convert_to_pdf_action = convert_to_pdf_action
        if job_id is not None:
            self.job_id = job_id
        if job_id_ext is not None:
            self.job_id_ext = job_id_ext
        if integrations is not None:
            self.integrations = integrations

    @property
    def document(self):
        """Gets the document of this ConvertToPdf.  # noqa: E501

        Document containing the data  # noqa: E501

        :return: The document of this ConvertToPdf.  # noqa: E501
        :rtype: Document
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this ConvertToPdf.

        Document containing the data  # noqa: E501

        :param document: The document of this ConvertToPdf.  # noqa: E501
        :type: Document
        """
        # # if document is None:
        # #     raise ValueError("Invalid value for `document`, must not be `None`")  # noqa: E501

        self._document = document

    @property
    def convert_to_pdf_action(self):
        """Gets the convert_to_pdf_action of this ConvertToPdf.  # noqa: E501

        Conversion configuration  # noqa: E501

        :return: The convert_to_pdf_action of this ConvertToPdf.  # noqa: E501
        :rtype: ConvertToPdfAction
        """
        return self._convert_to_pdf_action

    @convert_to_pdf_action.setter
    def convert_to_pdf_action(self, convert_to_pdf_action):
        """Sets the convert_to_pdf_action of this ConvertToPdf.

        Conversion configuration  # noqa: E501

        :param convert_to_pdf_action: The convert_to_pdf_action of this ConvertToPdf.  # noqa: E501
        :type: ConvertToPdfAction
        """

        self._convert_to_pdf_action = convert_to_pdf_action

    @property
    def job_id(self):
        """Gets the job_id of this ConvertToPdf.  # noqa: E501


        :return: The job_id of this ConvertToPdf.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ConvertToPdf.


        :param job_id: The job_id of this ConvertToPdf.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def job_id_ext(self):
        """Gets the job_id_ext of this ConvertToPdf.  # noqa: E501


        :return: The job_id_ext of this ConvertToPdf.  # noqa: E501
        :rtype: str
        """
        return self._job_id_ext

    @job_id_ext.setter
    def job_id_ext(self, job_id_ext):
        """Sets the job_id_ext of this ConvertToPdf.


        :param job_id_ext: The job_id_ext of this ConvertToPdf.  # noqa: E501
        :type: str
        """

        self._job_id_ext = job_id_ext

    @property
    def integrations(self):
        """Gets the integrations of this ConvertToPdf.  # noqa: E501


        :return: The integrations of this ConvertToPdf.  # noqa: E501
        :rtype: list[str]
        """
        return self._integrations

    @integrations.setter
    def integrations(self, integrations):
        """Sets the integrations of this ConvertToPdf.


        :param integrations: The integrations of this ConvertToPdf.  # noqa: E501
        :type: list[str]
        """

        self._integrations = integrations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConvertToPdf, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvertToPdf):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StorageFolder(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'storage_type': 'str',
        'folder_name': 'str',
        'host': 'str'
    }

    attribute_map = {
        'storage_type': 'storageType',
        'folder_name': 'folderName',
        'host': 'host'
    }

    def __init__(self, storage_type=None, folder_name=None, host=None):  # noqa: E501
        """StorageFolder - a model defined in Swagger"""  # noqa: E501

        self._storage_type = None
        self._folder_name = None
        self._host = None
        self.discriminator = None

        if storage_type is not None:
            self.storage_type = storage_type
        if folder_name is not None:
            self.folder_name = folder_name
        if host is not None:
            self.host = host

    @property
    def storage_type(self):
        """Gets the storage_type of this StorageFolder.  # noqa: E501


        :return: The storage_type of this StorageFolder.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this StorageFolder.


        :param storage_type: The storage_type of this StorageFolder.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "localSystem"]  # noqa: E501
        if storage_type not in allowed_values:
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    @property
    def folder_name(self):
        """Gets the folder_name of this StorageFolder.  # noqa: E501


        :return: The folder_name of this StorageFolder.  # noqa: E501
        :rtype: str
        """
        return self._folder_name

    @folder_name.setter
    def folder_name(self, folder_name):
        """Sets the folder_name of this StorageFolder.


        :param folder_name: The folder_name of this StorageFolder.  # noqa: E501
        :type: str
        """

        self._folder_name = folder_name

    @property
    def host(self):
        """Gets the host of this StorageFolder.  # noqa: E501


        :return: The host of this StorageFolder.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this StorageFolder.


        :param host: The host of this StorageFolder.  # noqa: E501
        :type: str
        """

        self._host = host

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StorageFolder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageFolder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DmsApi

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IFormFile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content_type': 'str',
        'content_disposition': 'str',
        'headers': 'dict(str, list[str])',
        'length': 'int',
        'name': 'str',
        'file_name': 'str'
    }

    attribute_map = {
        'content_type': 'contentType',
        'content_disposition': 'contentDisposition',
        'headers': 'headers',
        'length': 'length',
        'name': 'name',
        'file_name': 'fileName'
    }

    def __init__(self, content_type=None, content_disposition=None, headers=None, length=None, name=None, file_name=None):  # noqa: E501
        """IFormFile - a model defined in Swagger"""  # noqa: E501

        self._content_type = None
        self._content_disposition = None
        self._headers = None
        self._length = None
        self._name = None
        self._file_name = None
        self.discriminator = None

        if content_type is not None:
            self.content_type = content_type
        if content_disposition is not None:
            self.content_disposition = content_disposition
        if headers is not None:
            self.headers = headers
        if length is not None:
            self.length = length
        if name is not None:
            self.name = name
        if file_name is not None:
            self.file_name = file_name

    @property
    def content_type(self):
        """Gets the content_type of this IFormFile.  # noqa: E501


        :return: The content_type of this IFormFile.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this IFormFile.


        :param content_type: The content_type of this IFormFile.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def content_disposition(self):
        """Gets the content_disposition of this IFormFile.  # noqa: E501


        :return: The content_disposition of this IFormFile.  # noqa: E501
        :rtype: str
        """
        return self._content_disposition

    @content_disposition.setter
    def content_disposition(self, content_disposition):
        """Sets the content_disposition of this IFormFile.


        :param content_disposition: The content_disposition of this IFormFile.  # noqa: E501
        :type: str
        """

        self._content_disposition = content_disposition

    @property
    def headers(self):
        """Gets the headers of this IFormFile.  # noqa: E501


        :return: The headers of this IFormFile.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this IFormFile.


        :param headers: The headers of this IFormFile.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._headers = headers

    @property
    def length(self):
        """Gets the length of this IFormFile.  # noqa: E501


        :return: The length of this IFormFile.  # noqa: E501
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this IFormFile.


        :param length: The length of this IFormFile.  # noqa: E501
        :type: int
        """

        self._length = length

    @property
    def name(self):
        """Gets the name of this IFormFile.  # noqa: E501


        :return: The name of this IFormFile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IFormFile.


        :param name: The name of this IFormFile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def file_name(self):
        """Gets the file_name of this IFormFile.  # noqa: E501


        :return: The file_name of this IFormFile.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this IFormFile.


        :param file_name: The file_name of this IFormFile.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IFormFile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PageSelection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_nrs': 'list[int]',
        'page_ids': 'list[str]',
        'page_sequence': 'str'
    }

    attribute_map = {
        'page_nrs': 'pageNrs',
        'page_ids': 'pageIds',
        'page_sequence': 'pageSequence'
    }

    def __init__(self, page_nrs=None, page_ids=None, page_sequence=None):  # noqa: E501
        """PageSelection - a model defined in Swagger"""  # noqa: E501

        self._page_nrs = None
        self._page_ids = None
        self._page_sequence = None
        self.discriminator = None

        if page_nrs is not None:
            self.page_nrs = page_nrs
        if page_ids is not None:
            self.page_ids = page_ids
        if page_sequence is not None:
            self.page_sequence = page_sequence

    @property
    def page_nrs(self):
        """Gets the page_nrs of this PageSelection.  # noqa: E501

        Give a list of PageNrs to apply the action.<br />  PageNrs overruels PageIds and PageSequence  # noqa: E501

        :return: The page_nrs of this PageSelection.  # noqa: E501
        :rtype: list[int]
        """
        return self._page_nrs

    @page_nrs.setter
    def page_nrs(self, page_nrs):
        """Sets the page_nrs of this PageSelection.

        Give a list of PageNrs to apply the action.<br />  PageNrs overruels PageIds and PageSequence  # noqa: E501

        :param page_nrs: The page_nrs of this PageSelection.  # noqa: E501
        :type: list[int]
        """

        self._page_nrs = page_nrs

    @property
    def page_ids(self):
        """Gets the page_ids of this PageSelection.  # noqa: E501

        Give a List of PagesIds to apply the action.<br />  PageIds overrules the PageSequence  # noqa: E501

        :return: The page_ids of this PageSelection.  # noqa: E501
        :rtype: list[str]
        """
        return self._page_ids

    @page_ids.setter
    def page_ids(self, page_ids):
        """Sets the page_ids of this PageSelection.

        Give a List of PagesIds to apply the action.<br />  PageIds overrules the PageSequence  # noqa: E501

        :param page_ids: The page_ids of this PageSelection.  # noqa: E501
        :type: list[str]
        """

        self._page_ids = page_ids

    @property
    def page_sequence(self):
        """Gets the page_sequence of this PageSelection.  # noqa: E501

        {default: PageSelection.All}  # noqa: E501

        :return: The page_sequence of this PageSelection.  # noqa: E501
        :rtype: str
        """
        return self._page_sequence

    @page_sequence.setter
    def page_sequence(self, page_sequence):
        """Sets the page_sequence of this PageSelection.

        {default: PageSelection.All}  # noqa: E501

        :param page_sequence: The page_sequence of this PageSelection.  # noqa: E501
        :type: str
        """
        allowed_values = ["all", "first", "last", "odd", "even", "notFirst", "notLast"]  # noqa: E501
        if page_sequence not in allowed_values:
            raise ValueError(
                "Invalid value for `page_sequence` ({0}), must be one of {1}"  # noqa: E501
                .format(page_sequence, allowed_values)
            )

        self._page_sequence = page_sequence

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PageSelection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageSelection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RepairAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'analyze_only': 'bool',
        'recover_pages': 'bool',
        'recover_xref': 'bool',
        'rebuild_fonts': 'bool',
        'rebuild_fonts_as_type1': 'bool',
        'rebuild_streams': 'bool'
    }

    attribute_map = {
        'analyze_only': 'analyzeOnly',
        'recover_pages': 'recoverPages',
        'recover_xref': 'recoverXREF',
        'rebuild_fonts': 'rebuildFonts',
        'rebuild_fonts_as_type1': 'rebuildFontsAsType1',
        'rebuild_streams': 'rebuildStreams'
    }

    def __init__(self, analyze_only=None, recover_pages=None, recover_xref=None, rebuild_fonts=None, rebuild_fonts_as_type1=None, rebuild_streams=None):  # noqa: E501
        """RepairAction - a model defined in Swagger"""  # noqa: E501

        self._analyze_only = None
        self._recover_pages = None
        self._recover_xref = None
        self._rebuild_fonts = None
        self._rebuild_fonts_as_type1 = None
        self._rebuild_streams = None
        self.discriminator = None

        if analyze_only is not None:
            self.analyze_only = analyze_only
        if recover_pages is not None:
            self.recover_pages = recover_pages
        if recover_xref is not None:
            self.recover_xref = recover_xref
        if rebuild_fonts is not None:
            self.rebuild_fonts = rebuild_fonts
        if rebuild_fonts_as_type1 is not None:
            self.rebuild_fonts_as_type1 = rebuild_fonts_as_type1
        if rebuild_streams is not None:
            self.rebuild_streams = rebuild_streams

    @property
    def analyze_only(self):
        """Gets the analyze_only of this RepairAction.  # noqa: E501


        :return: The analyze_only of this RepairAction.  # noqa: E501
        :rtype: bool
        """
        return self._analyze_only

    @analyze_only.setter
    def analyze_only(self, analyze_only):
        """Sets the analyze_only of this RepairAction.


        :param analyze_only: The analyze_only of this RepairAction.  # noqa: E501
        :type: bool
        """

        self._analyze_only = analyze_only

    @property
    def recover_pages(self):
        """Gets the recover_pages of this RepairAction.  # noqa: E501


        :return: The recover_pages of this RepairAction.  # noqa: E501
        :rtype: bool
        """
        return self._recover_pages

    @recover_pages.setter
    def recover_pages(self, recover_pages):
        """Sets the recover_pages of this RepairAction.


        :param recover_pages: The recover_pages of this RepairAction.  # noqa: E501
        :type: bool
        """

        self._recover_pages = recover_pages

    @property
    def recover_xref(self):
        """Gets the recover_xref of this RepairAction.  # noqa: E501


        :return: The recover_xref of this RepairAction.  # noqa: E501
        :rtype: bool
        """
        return self._recover_xref

    @recover_xref.setter
    def recover_xref(self, recover_xref):
        """Sets the recover_xref of this RepairAction.


        :param recover_xref: The recover_xref of this RepairAction.  # noqa: E501
        :type: bool
        """

        self._recover_xref = recover_xref

    @property
    def rebuild_fonts(self):
        """Gets the rebuild_fonts of this RepairAction.  # noqa: E501


        :return: The rebuild_fonts of this RepairAction.  # noqa: E501
        :rtype: bool
        """
        return self._rebuild_fonts

    @rebuild_fonts.setter
    def rebuild_fonts(self, rebuild_fonts):
        """Sets the rebuild_fonts of this RepairAction.


        :param rebuild_fonts: The rebuild_fonts of this RepairAction.  # noqa: E501
        :type: bool
        """

        self._rebuild_fonts = rebuild_fonts

    @property
    def rebuild_fonts_as_type1(self):
        """Gets the rebuild_fonts_as_type1 of this RepairAction.  # noqa: E501


        :return: The rebuild_fonts_as_type1 of this RepairAction.  # noqa: E501
        :rtype: bool
        """
        return self._rebuild_fonts_as_type1

    @rebuild_fonts_as_type1.setter
    def rebuild_fonts_as_type1(self, rebuild_fonts_as_type1):
        """Sets the rebuild_fonts_as_type1 of this RepairAction.


        :param rebuild_fonts_as_type1: The rebuild_fonts_as_type1 of this RepairAction.  # noqa: E501
        :type: bool
        """

        self._rebuild_fonts_as_type1 = rebuild_fonts_as_type1

    @property
    def rebuild_streams(self):
        """Gets the rebuild_streams of this RepairAction.  # noqa: E501


        :return: The rebuild_streams of this RepairAction.  # noqa: E501
        :rtype: bool
        """
        return self._rebuild_streams

    @rebuild_streams.setter
    def rebuild_streams(self, rebuild_streams):
        """Sets the rebuild_streams of this RepairAction.


        :param rebuild_streams: The rebuild_streams of this RepairAction.  # noqa: E501
        :type: bool
        """

        self._rebuild_streams = rebuild_streams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RepairAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepairAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SigningProvider(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'signing_provider_type': 'str',
        'identity': 'str',
        'profile': 'str',
        'secret': 'str',
        'client_id': 'str',
        'pin': 'str',
        'service_url': 'str'
    }

    attribute_map = {
        'signing_provider_type': 'signingProviderType',
        'identity': 'identity',
        'profile': 'profile',
        'secret': 'secret',
        'client_id': 'clientId',
        'pin': 'pin',
        'service_url': 'serviceUrl'
    }

    def __init__(self, signing_provider_type=None, identity=None, profile=None, secret=None, client_id=None, pin=None, service_url=None):  # noqa: E501
        """SigningProvider - a model defined in Swagger"""  # noqa: E501

        self._signing_provider_type = None
        self._identity = None
        self._profile = None
        self._secret = None
        self._client_id = None
        self._pin = None
        self._service_url = None
        self.discriminator = None

        if signing_provider_type is not None:
            self.signing_provider_type = signing_provider_type
        if identity is not None:
            self.identity = identity
        if profile is not None:
            self.profile = profile
        if secret is not None:
            self.secret = secret
        if client_id is not None:
            self.client_id = client_id
        if pin is not None:
            self.pin = pin
        if service_url is not None:
            self.service_url = service_url

    @property
    def signing_provider_type(self):
        """Gets the signing_provider_type of this SigningProvider.  # noqa: E501


        :return: The signing_provider_type of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._signing_provider_type

    @signing_provider_type.setter
    def signing_provider_type(self, signing_provider_type):
        """Sets the signing_provider_type of this SigningProvider.


        :param signing_provider_type: The signing_provider_type of this SigningProvider.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "quoVadisSealsign", "swissSignSuisseID", "swisscomSigning"]  # noqa: E501
        if signing_provider_type not in allowed_values:
            raise ValueError(
                "Invalid value for `signing_provider_type` ({0}), must be one of {1}"  # noqa: E501
                .format(signing_provider_type, allowed_values)
            )

        self._signing_provider_type = signing_provider_type

    @property
    def identity(self):
        """Gets the identity of this SigningProvider.  # noqa: E501


        :return: The identity of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """Sets the identity of this SigningProvider.


        :param identity: The identity of this SigningProvider.  # noqa: E501
        :type: str
        """

        self._identity = identity

    @property
    def profile(self):
        """Gets the profile of this SigningProvider.  # noqa: E501


        :return: The profile of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this SigningProvider.


        :param profile: The profile of this SigningProvider.  # noqa: E501
        :type: str
        """

        self._profile = profile

    @property
    def secret(self):
        """Gets the secret of this SigningProvider.  # noqa: E501


        :return: The secret of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this SigningProvider.


        :param secret: The secret of this SigningProvider.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def client_id(self):
        """Gets the client_id of this SigningProvider.  # noqa: E501


        :return: The client_id of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this SigningProvider.


        :param client_id: The client_id of this SigningProvider.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def pin(self):
        """Gets the pin of this SigningProvider.  # noqa: E501


        :return: The pin of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._pin

    @pin.setter
    def pin(self, pin):
        """Sets the pin of this SigningProvider.


        :param pin: The pin of this SigningProvider.  # noqa: E501
        :type: str
        """

        self._pin = pin

    @property
    def service_url(self):
        """Gets the service_url of this SigningProvider.  # noqa: E501


        :return: The service_url of this SigningProvider.  # noqa: E501
        :rtype: str
        """
        return self._service_url

    @service_url.setter
    def service_url(self, service_url):
        """Sets the service_url of this SigningProvider.


        :param service_url: The service_url of this SigningProvider.  # noqa: E501
        :type: str
        """

        self._service_url = service_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SigningProvider, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SigningProvider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_action import DocAction  # noqa: F401,E501
from pdf4me.model.doc_log import DocLog  # noqa: F401,E501
from pdf4me.model.doc_metadata import DocMetadata  # noqa: F401,E501
from pdf4me.model.page import Page  # noqa: F401,E501


class Pdf4meDocument(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_type': 'str',
        'blob_ref': 'str',
        'job_id': 'str',
        'ref_document_id': 'str',
        'ref_doc_action': 'DocAction',
        'document_id': 'str',
        'user_id': 'str',
        'name': 'str',
        'file_name': 'str',
        'file_extension': 'str',
        'ratio': 'float',
        'doc_status': 'str',
        'in_execution': 'bool',
        'order': 'int',
        'show_doc': 'bool',
        'doc_data': 'str',
        'thumbnail': 'str',
        'pages': 'list[Page]',
        'thumbnails': 'list[str]',
        'doc_logs': 'list[DocLog]',
        'doc_metadata': 'DocMetadata',
        'original_doc_metadata': 'DocMetadata',
        'storage_provider_broker': 'str',
        'storage_provider': 'str',
        'storage_account_id': 'str',
        'storage_provider_id': 'str',
        'storage_provider_folder_id': 'str',
        'document_url': 'str'
    }

    attribute_map = {
        'document_type': 'documentType',
        'blob_ref': 'blobRef',
        'job_id': 'jobId',
        'ref_document_id': 'refDocumentId',
        'ref_doc_action': 'refDocAction',
        'document_id': 'documentId',
        'user_id': 'userId',
        'name': 'name',
        'file_name': 'fileName',
        'file_extension': 'fileExtension',
        'ratio': 'ratio',
        'doc_status': 'docStatus',
        'in_execution': 'inExecution',
        'order': 'order',
        'show_doc': 'showDoc',
        'doc_data': 'docData',
        'thumbnail': 'thumbnail',
        'pages': 'pages',
        'thumbnails': 'thumbnails',
        'doc_logs': 'docLogs',
        'doc_metadata': 'docMetadata',
        'original_doc_metadata': 'originalDocMetadata',
        'storage_provider_broker': 'storageProviderBroker',
        'storage_provider': 'storageProvider',
        'storage_account_id': 'storageAccountId',
        'storage_provider_id': 'storageProviderId',
        'storage_provider_folder_id': 'storageProviderFolderId',
        'document_url': 'documentUrl'
    }

    def __init__(self, document_type=None, blob_ref=None, job_id=None, ref_document_id=None, ref_doc_action=None, document_id=None, user_id=None, name=None, file_name=None, file_extension=None, ratio=None, doc_status=None, in_execution=None, order=None, show_doc=None, doc_data=None, thumbnail=None, pages=None, thumbnails=None, doc_logs=None, doc_metadata=None, original_doc_metadata=None, storage_provider_broker=None, storage_provider=None, storage_account_id=None, storage_provider_id=None, storage_provider_folder_id=None, document_url=None):  # noqa: E501
        """Pdf4meDocument - a model defined in Swagger"""  # noqa: E501

        self._document_type = None
        self._blob_ref = None
        self._job_id = None
        self._ref_document_id = None
        self._ref_doc_action = None
        self._document_id = None
        self._user_id = None
        self._name = None
        self._file_name = None
        self._file_extension = None
        self._ratio = None
        self._doc_status = None
        self._in_execution = None
        self._order = None
        self._show_doc = None
        self._doc_data = None
        self._thumbnail = None
        self._pages = None
        self._thumbnails = None
        self._doc_logs = None
        self._doc_metadata = None
        self._original_doc_metadata = None
        self._storage_provider_broker = None
        self._storage_provider = None
        self._storage_account_id = None
        self._storage_provider_id = None
        self._storage_provider_folder_id = None
        self._document_url = None
        self.discriminator = None

        if document_type is not None:
            self.document_type = document_type
        if blob_ref is not None:
            self.blob_ref = blob_ref
        if job_id is not None:
            self.job_id = job_id
        if ref_document_id is not None:
            self.ref_document_id = ref_document_id
        if ref_doc_action is not None:
            self.ref_doc_action = ref_doc_action
        if document_id is not None:
            self.document_id = document_id
        if user_id is not None:
            self.user_id = user_id
        if name is not None:
            self.name = name
        if file_name is not None:
            self.file_name = file_name
        if file_extension is not None:
            self.file_extension = file_extension
        if ratio is not None:
            self.ratio = ratio
        if doc_status is not None:
            self.doc_status = doc_status
        if in_execution is not None:
            self.in_execution = in_execution
        if order is not None:
            self.order = order
        if show_doc is not None:
            self.show_doc = show_doc
        if doc_data is not None:
            self.doc_data = doc_data
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if pages is not None:
            self.pages = pages
        if thumbnails is not None:
            self.thumbnails = thumbnails
        if doc_logs is not None:
            self.doc_logs = doc_logs
        if doc_metadata is not None:
            self.doc_metadata = doc_metadata
        if original_doc_metadata is not None:
            self.original_doc_metadata = original_doc_metadata
        if storage_provider_broker is not None:
            self.storage_provider_broker = storage_provider_broker
        if storage_provider is not None:
            self.storage_provider = storage_provider
        if storage_account_id is not None:
            self.storage_account_id = storage_account_id
        if storage_provider_id is not None:
            self.storage_provider_id = storage_provider_id
        if storage_provider_folder_id is not None:
            self.storage_provider_folder_id = storage_provider_folder_id
        if document_url is not None:
            self.document_url = document_url

    @property
    def document_type(self):
        """Gets the document_type of this Pdf4meDocument.  # noqa: E501


        :return: The document_type of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this Pdf4meDocument.


        :param document_type: The document_type of this Pdf4meDocument.  # noqa: E501
        :type: str
        """
        allowed_values = ["uploadDoc", "converted", "stamped", "ocr", "split", "optimize", "merge"]  # noqa: E501
        if document_type not in allowed_values:
            raise ValueError(
                "Invalid value for `document_type` ({0}), must be one of {1}"  # noqa: E501
                .format(document_type, allowed_values)
            )

        self._document_type = document_type

    @property
    def blob_ref(self):
        """Gets the blob_ref of this Pdf4meDocument.  # noqa: E501


        :return: The blob_ref of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._blob_ref

    @blob_ref.setter
    def blob_ref(self, blob_ref):
        """Sets the blob_ref of this Pdf4meDocument.


        :param blob_ref: The blob_ref of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._blob_ref = blob_ref

    @property
    def job_id(self):
        """Gets the job_id of this Pdf4meDocument.  # noqa: E501


        :return: The job_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this Pdf4meDocument.


        :param job_id: The job_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def ref_document_id(self):
        """Gets the ref_document_id of this Pdf4meDocument.  # noqa: E501


        :return: The ref_document_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._ref_document_id

    @ref_document_id.setter
    def ref_document_id(self, ref_document_id):
        """Sets the ref_document_id of this Pdf4meDocument.


        :param ref_document_id: The ref_document_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._ref_document_id = ref_document_id

    @property
    def ref_doc_action(self):
        """Gets the ref_doc_action of this Pdf4meDocument.  # noqa: E501


        :return: The ref_doc_action of this Pdf4meDocument.  # noqa: E501
        :rtype: DocAction
        """
        return self._ref_doc_action

    @ref_doc_action.setter
    def ref_doc_action(self, ref_doc_action):
        """Sets the ref_doc_action of this Pdf4meDocument.


        :param ref_doc_action: The ref_doc_action of this Pdf4meDocument.  # noqa: E501
        :type: DocAction
        """

        self._ref_doc_action = ref_doc_action

    @property
    def document_id(self):
        """Gets the document_id of this Pdf4meDocument.  # noqa: E501


        :return: The document_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this Pdf4meDocument.


        :param document_id: The document_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def user_id(self):
        """Gets the user_id of this Pdf4meDocument.  # noqa: E501


        :return: The user_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Pdf4meDocument.


        :param user_id: The user_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this Pdf4meDocument.  # noqa: E501


        :return: The name of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Pdf4meDocument.


        :param name: The name of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def file_name(self):
        """Gets the file_name of this Pdf4meDocument.  # noqa: E501


        :return: The file_name of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Pdf4meDocument.


        :param file_name: The file_name of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def file_extension(self):
        """Gets the file_extension of this Pdf4meDocument.  # noqa: E501


        :return: The file_extension of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._file_extension

    @file_extension.setter
    def file_extension(self, file_extension):
        """Sets the file_extension of this Pdf4meDocument.


        :param file_extension: The file_extension of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._file_extension = file_extension

    @property
    def ratio(self):
        """Gets the ratio of this Pdf4meDocument.  # noqa: E501


        :return: The ratio of this Pdf4meDocument.  # noqa: E501
        :rtype: float
        """
        return self._ratio

    @ratio.setter
    def ratio(self, ratio):
        """Sets the ratio of this Pdf4meDocument.


        :param ratio: The ratio of this Pdf4meDocument.  # noqa: E501
        :type: float
        """

        self._ratio = ratio

    @property
    def doc_status(self):
        """Gets the doc_status of this Pdf4meDocument.  # noqa: E501


        :return: The doc_status of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._doc_status

    @doc_status.setter
    def doc_status(self, doc_status):
        """Sets the doc_status of this Pdf4meDocument.


        :param doc_status: The doc_status of this Pdf4meDocument.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "error", "finished", "uploaded", "loading", "loaded", "converting", "converted", "optimizing", "optimized", "doingOcr", "ocred", "doingZip", "stamping", "stamped", "processing", "signed"]  # noqa: E501
        if doc_status not in allowed_values:
            raise ValueError(
                "Invalid value for `doc_status` ({0}), must be one of {1}"  # noqa: E501
                .format(doc_status, allowed_values)
            )

        self._doc_status = doc_status

    @property
    def in_execution(self):
        """Gets the in_execution of this Pdf4meDocument.  # noqa: E501


        :return: The in_execution of this Pdf4meDocument.  # noqa: E501
        :rtype: bool
        """
        return self._in_execution

    @in_execution.setter
    def in_execution(self, in_execution):
        """Sets the in_execution of this Pdf4meDocument.


        :param in_execution: The in_execution of this Pdf4meDocument.  # noqa: E501
        :type: bool
        """

        self._in_execution = in_execution

    @property
    def order(self):
        """Gets the order of this Pdf4meDocument.  # noqa: E501


        :return: The order of this Pdf4meDocument.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Pdf4meDocument.


        :param order: The order of this Pdf4meDocument.  # noqa: E501
        :type: int
        """

        self._order = order

    @property
    def show_doc(self):
        """Gets the show_doc of this Pdf4meDocument.  # noqa: E501


        :return: The show_doc of this Pdf4meDocument.  # noqa: E501
        :rtype: bool
        """
        return self._show_doc

    @show_doc.setter
    def show_doc(self, show_doc):
        """Sets the show_doc of this Pdf4meDocument.


        :param show_doc: The show_doc of this Pdf4meDocument.  # noqa: E501
        :type: bool
        """

        self._show_doc = show_doc

    @property
    def doc_data(self):
        """Gets the doc_data of this Pdf4meDocument.  # noqa: E501


        :return: The doc_data of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._doc_data

    @doc_data.setter
    def doc_data(self, doc_data):
        """Sets the doc_data of this Pdf4meDocument.


        :param doc_data: The doc_data of this Pdf4meDocument.  # noqa: E501
        :type: str
        """
        if doc_data is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', doc_data):  # noqa: E501
            raise ValueError(r"Invalid value for `doc_data`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._doc_data = doc_data

    @property
    def thumbnail(self):
        """Gets the thumbnail of this Pdf4meDocument.  # noqa: E501


        :return: The thumbnail of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this Pdf4meDocument.


        :param thumbnail: The thumbnail of this Pdf4meDocument.  # noqa: E501
        :type: str
        """
        if thumbnail is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', thumbnail):  # noqa: E501
            raise ValueError(r"Invalid value for `thumbnail`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._thumbnail = thumbnail

    @property
    def pages(self):
        """Gets the pages of this Pdf4meDocument.  # noqa: E501


        :return: The pages of this Pdf4meDocument.  # noqa: E501
        :rtype: list[Page]
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this Pdf4meDocument.


        :param pages: The pages of this Pdf4meDocument.  # noqa: E501
        :type: list[Page]
        """

        self._pages = pages

    @property
    def thumbnails(self):
        """Gets the thumbnails of this Pdf4meDocument.  # noqa: E501


        :return: The thumbnails of this Pdf4meDocument.  # noqa: E501
        :rtype: list[str]
        """
        return self._thumbnails

    @thumbnails.setter
    def thumbnails(self, thumbnails):
        """Sets the thumbnails of this Pdf4meDocument.


        :param thumbnails: The thumbnails of this Pdf4meDocument.  # noqa: E501
        :type: list[str]
        """

        self._thumbnails = thumbnails

    @property
    def doc_logs(self):
        """Gets the doc_logs of this Pdf4meDocument.  # noqa: E501


        :return: The doc_logs of this Pdf4meDocument.  # noqa: E501
        :rtype: list[DocLog]
        """
        return self._doc_logs

    @doc_logs.setter
    def doc_logs(self, doc_logs):
        """Sets the doc_logs of this Pdf4meDocument.


        :param doc_logs: The doc_logs of this Pdf4meDocument.  # noqa: E501
        :type: list[DocLog]
        """

        self._doc_logs = doc_logs

    @property
    def doc_metadata(self):
        """Gets the doc_metadata of this Pdf4meDocument.  # noqa: E501


        :return: The doc_metadata of this Pdf4meDocument.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._doc_metadata

    @doc_metadata.setter
    def doc_metadata(self, doc_metadata):
        """Sets the doc_metadata of this Pdf4meDocument.


        :param doc_metadata: The doc_metadata of this Pdf4meDocument.  # noqa: E501
        :type: DocMetadata
        """

        self._doc_metadata = doc_metadata

    @property
    def original_doc_metadata(self):
        """Gets the original_doc_metadata of this Pdf4meDocument.  # noqa: E501


        :return: The original_doc_metadata of this Pdf4meDocument.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._original_doc_metadata

    @original_doc_metadata.setter
    def original_doc_metadata(self, original_doc_metadata):
        """Sets the original_doc_metadata of this Pdf4meDocument.


        :param original_doc_metadata: The original_doc_metadata of this Pdf4meDocument.  # noqa: E501
        :type: DocMetadata
        """

        self._original_doc_metadata = original_doc_metadata

    @property
    def storage_provider_broker(self):
        """Gets the storage_provider_broker of this Pdf4meDocument.  # noqa: E501


        :return: The storage_provider_broker of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._storage_provider_broker

    @storage_provider_broker.setter
    def storage_provider_broker(self, storage_provider_broker):
        """Sets the storage_provider_broker of this Pdf4meDocument.


        :param storage_provider_broker: The storage_provider_broker of this Pdf4meDocument.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "kloudless"]  # noqa: E501
        if storage_provider_broker not in allowed_values:
            raise ValueError(
                "Invalid value for `storage_provider_broker` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_provider_broker, allowed_values)
            )

        self._storage_provider_broker = storage_provider_broker

    @property
    def storage_provider(self):
        """Gets the storage_provider of this Pdf4meDocument.  # noqa: E501


        :return: The storage_provider of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._storage_provider

    @storage_provider.setter
    def storage_provider(self, storage_provider):
        """Sets the storage_provider of this Pdf4meDocument.


        :param storage_provider: The storage_provider of this Pdf4meDocument.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "local", "url", "oneDrive", "dropbox", "googleDrive", "kloudless"]  # noqa: E501
        if storage_provider not in allowed_values:
            raise ValueError(
                "Invalid value for `storage_provider` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_provider, allowed_values)
            )

        self._storage_provider = storage_provider

    @property
    def storage_account_id(self):
        """Gets the storage_account_id of this Pdf4meDocument.  # noqa: E501


        :return: The storage_account_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._storage_account_id

    @storage_account_id.setter
    def storage_account_id(self, storage_account_id):
        """Sets the storage_account_id of this Pdf4meDocument.


        :param storage_account_id: The storage_account_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._storage_account_id = storage_account_id

    @property
    def storage_provider_id(self):
        """Gets the storage_provider_id of this Pdf4meDocument.  # noqa: E501


        :return: The storage_provider_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._storage_provider_id

    @storage_provider_id.setter
    def storage_provider_id(self, storage_provider_id):
        """Sets the storage_provider_id of this Pdf4meDocument.


        :param storage_provider_id: The storage_provider_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._storage_provider_id = storage_provider_id

    @property
    def storage_provider_folder_id(self):
        """Gets the storage_provider_folder_id of this Pdf4meDocument.  # noqa: E501


        :return: The storage_provider_folder_id of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._storage_provider_folder_id

    @storage_provider_folder_id.setter
    def storage_provider_folder_id(self, storage_provider_folder_id):
        """Sets the storage_provider_folder_id of this Pdf4meDocument.


        :param storage_provider_folder_id: The storage_provider_folder_id of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._storage_provider_folder_id = storage_provider_folder_id

    @property
    def document_url(self):
        """Gets the document_url of this Pdf4meDocument.  # noqa: E501


        :return: The document_url of this Pdf4meDocument.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this Pdf4meDocument.


        :param document_url: The document_url of this Pdf4meDocument.  # noqa: E501
        :type: str
        """

        self._document_url = document_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Pdf4meDocument, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pdf4meDocument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExecutionTrigger(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_time': 'datetime',
        'cron_trigger': 'str',
        'continues': 'bool'
    }

    attribute_map = {
        'start_time': 'startTime',
        'cron_trigger': 'cronTrigger',
        'continues': 'continues'
    }

    def __init__(self, start_time=None, cron_trigger=None, continues=None):  # noqa: E501
        """ExecutionTrigger - a model defined in Swagger"""  # noqa: E501

        self._start_time = None
        self._cron_trigger = None
        self._continues = None
        self.discriminator = None

        if start_time is not None:
            self.start_time = start_time
        if cron_trigger is not None:
            self.cron_trigger = cron_trigger
        if continues is not None:
            self.continues = continues

    @property
    def start_time(self):
        """Gets the start_time of this ExecutionTrigger.  # noqa: E501


        :return: The start_time of this ExecutionTrigger.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ExecutionTrigger.


        :param start_time: The start_time of this ExecutionTrigger.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def cron_trigger(self):
        """Gets the cron_trigger of this ExecutionTrigger.  # noqa: E501


        :return: The cron_trigger of this ExecutionTrigger.  # noqa: E501
        :rtype: str
        """
        return self._cron_trigger

    @cron_trigger.setter
    def cron_trigger(self, cron_trigger):
        """Sets the cron_trigger of this ExecutionTrigger.


        :param cron_trigger: The cron_trigger of this ExecutionTrigger.  # noqa: E501
        :type: str
        """

        self._cron_trigger = cron_trigger

    @property
    def continues(self):
        """Gets the continues of this ExecutionTrigger.  # noqa: E501


        :return: The continues of this ExecutionTrigger.  # noqa: E501
        :rtype: bool
        """
        return self._continues

    @continues.setter
    def continues(self, continues):
        """Sets the continues of this ExecutionTrigger.


        :param continues: The continues of this ExecutionTrigger.  # noqa: E501
        :type: bool
        """

        self._continues = continues

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExecutionTrigger, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecutionTrigger):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class Pdf4meClientException(Exception):
    """Raised when wrong arguments have been provided."""

    def __init__(self, msg):
        self.msg = msg
        Exception.__init__(self, msg)


class Pdf4meBackendException(Exception):
    """Raised when an error on the back-end occurred."""

    def __init__(self, msg):
        self.msg = msg
        Exception.__init__(self, msg)



from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import Stamp


class StampClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def stamp(self, stamp):
        """The predefined stamp is carried out.

        :param stamp: stamp configuration
        :type stamp: Stamp
        :return: StampRes, contains the stamped PDF
        """

        # check stamp validity
        self.__check_stamp_object_validity(stamp)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=stamp, controller='Stamp/Stamp')

        return res

    def text_stamp(self, text, pages, align_x, align_y, file):
        """Places a custom text stamp on the pages of your choice. The position of the stamp is specified by alignX and alignY.

        :param text: custom text on stamp
        :type text: str
        :param pages: pages to be stamped
        :type pages: str: {'all', 'first', 'last', 'odd', 'even', 'notFirst', 'otLast'} or a list of comma separated page numbers e.g. '1,4', if the first and fourth page need to be stamped
        :param align_x: horizontal position
        :type align_x: str: {'left', 'center', 'right'}
        :param align_y: vertical position
        :type align_y: str: {'top', 'middle', 'bottom'}
        :param file: to be stamped
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('text', text), ('pages', pages), ('alignX', align_x), ('alignY', align_y)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Stamp/TextStamp')

    def __check_stamp_object_validity(self, stamp):
        """checks whether the stamp object contains the essential information to be
        processed by the server."""

        if stamp is None:
            raise Pdf4meClientException('The stamp parameter cannot be None.')
        elif stamp.document is None or stamp.document.doc_data is None:
            raise Pdf4meClientException('The stamp document cannot be None.')
        elif stamp.stamp_action is None:
            raise Pdf4meClientException('The stamp_action cannot be None.')
        elif stamp.stamp_action.alpha is None:
            raise Pdf4meClientException('The alpha parameter of stamp_action cannot be None.')
        elif stamp.stamp_action.text is None and stamp.stamp_action.image is None:
            raise Pdf4meClientException('The image and text parameter of stampAction cannot both be None.')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SplitAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'split_after_page': 'int',
        'split_sequence': 'list[int]',
        'recurring_split_after_page': 'int',
        'barcode_starts_with': 'str'
    }

    attribute_map = {
        'split_after_page': 'splitAfterPage',
        'split_sequence': 'splitSequence',
        'recurring_split_after_page': 'recurringSplitAfterPage',
        'barcode_starts_with': 'barcodeStartsWith'
    }

    def __init__(self, split_after_page=None, split_sequence=None, recurring_split_after_page=None, barcode_starts_with=None):  # noqa: E501
        """SplitAction - a model defined in Swagger"""  # noqa: E501

        self._split_after_page = None
        self._split_sequence = None
        self._recurring_split_after_page = None
        self._barcode_starts_with = None
        self.discriminator = None

        if split_after_page is not None:
            self.split_after_page = split_after_page
        if split_sequence is not None:
            self.split_sequence = split_sequence
        if recurring_split_after_page is not None:
            self.recurring_split_after_page = recurring_split_after_page
        if barcode_starts_with is not None:
            self.barcode_starts_with = barcode_starts_with

    @property
    def split_after_page(self):
        """Gets the split_after_page of this SplitAction.  # noqa: E501


        :return: The split_after_page of this SplitAction.  # noqa: E501
        :rtype: int
        """
        return self._split_after_page

    @split_after_page.setter
    def split_after_page(self, split_after_page):
        """Sets the split_after_page of this SplitAction.


        :param split_after_page: The split_after_page of this SplitAction.  # noqa: E501
        :type: int
        """

        self._split_after_page = split_after_page

    @property
    def split_sequence(self):
        """Gets the split_sequence of this SplitAction.  # noqa: E501


        :return: The split_sequence of this SplitAction.  # noqa: E501
        :rtype: list[int]
        """
        return self._split_sequence

    @split_sequence.setter
    def split_sequence(self, split_sequence):
        """Sets the split_sequence of this SplitAction.


        :param split_sequence: The split_sequence of this SplitAction.  # noqa: E501
        :type: list[int]
        """

        self._split_sequence = split_sequence

    @property
    def recurring_split_after_page(self):
        """Gets the recurring_split_after_page of this SplitAction.  # noqa: E501


        :return: The recurring_split_after_page of this SplitAction.  # noqa: E501
        :rtype: int
        """
        return self._recurring_split_after_page

    @recurring_split_after_page.setter
    def recurring_split_after_page(self, recurring_split_after_page):
        """Sets the recurring_split_after_page of this SplitAction.


        :param recurring_split_after_page: The recurring_split_after_page of this SplitAction.  # noqa: E501
        :type: int
        """

        self._recurring_split_after_page = recurring_split_after_page

    @property
    def barcode_starts_with(self):
        """Gets the barcode_starts_with of this SplitAction.  # noqa: E501


        :return: The barcode_starts_with of this SplitAction.  # noqa: E501
        :rtype: str
        """
        return self._barcode_starts_with

    @barcode_starts_with.setter
    def barcode_starts_with(self, barcode_starts_with):
        """Sets the barcode_starts_with of this SplitAction.


        :param barcode_starts_with: The barcode_starts_with of this SplitAction.  # noqa: E501
        :type: str
        """

        self._barcode_starts_with = barcode_starts_with

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SplitAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplitAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IntegrationCall(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'integration_name': 'str',
        'integration_type': 'str',
        'integration_id': 'str',
        'status': 'str',
        'error_message': 'str',
        'retries': 'int',
        'last_call_time': 'datetime'
    }

    attribute_map = {
        'integration_name': 'integrationName',
        'integration_type': 'integrationType',
        'integration_id': 'integrationId',
        'status': 'status',
        'error_message': 'errorMessage',
        'retries': 'retries',
        'last_call_time': 'lastCallTime'
    }

    def __init__(self, integration_name=None, integration_type=None, integration_id=None, status=None, error_message=None, retries=None, last_call_time=None):  # noqa: E501
        """IntegrationCall - a model defined in Swagger"""  # noqa: E501

        self._integration_name = None
        self._integration_type = None
        self._integration_id = None
        self._status = None
        self._error_message = None
        self._retries = None
        self._last_call_time = None
        self.discriminator = None

        if integration_name is not None:
            self.integration_name = integration_name
        if integration_type is not None:
            self.integration_type = integration_type
        if integration_id is not None:
            self.integration_id = integration_id
        if status is not None:
            self.status = status
        if error_message is not None:
            self.error_message = error_message
        if retries is not None:
            self.retries = retries
        if last_call_time is not None:
            self.last_call_time = last_call_time

    @property
    def integration_name(self):
        """Gets the integration_name of this IntegrationCall.  # noqa: E501


        :return: The integration_name of this IntegrationCall.  # noqa: E501
        :rtype: str
        """
        return self._integration_name

    @integration_name.setter
    def integration_name(self, integration_name):
        """Sets the integration_name of this IntegrationCall.


        :param integration_name: The integration_name of this IntegrationCall.  # noqa: E501
        :type: str
        """

        self._integration_name = integration_name

    @property
    def integration_type(self):
        """Gets the integration_type of this IntegrationCall.  # noqa: E501


        :return: The integration_type of this IntegrationCall.  # noqa: E501
        :rtype: str
        """
        return self._integration_type

    @integration_type.setter
    def integration_type(self, integration_type):
        """Sets the integration_type of this IntegrationCall.


        :param integration_type: The integration_type of this IntegrationCall.  # noqa: E501
        :type: str
        """

        self._integration_type = integration_type

    @property
    def integration_id(self):
        """Gets the integration_id of this IntegrationCall.  # noqa: E501


        :return: The integration_id of this IntegrationCall.  # noqa: E501
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this IntegrationCall.


        :param integration_id: The integration_id of this IntegrationCall.  # noqa: E501
        :type: str
        """

        self._integration_id = integration_id

    @property
    def status(self):
        """Gets the status of this IntegrationCall.  # noqa: E501


        :return: The status of this IntegrationCall.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this IntegrationCall.


        :param status: The status of this IntegrationCall.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def error_message(self):
        """Gets the error_message of this IntegrationCall.  # noqa: E501


        :return: The error_message of this IntegrationCall.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this IntegrationCall.


        :param error_message: The error_message of this IntegrationCall.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def retries(self):
        """Gets the retries of this IntegrationCall.  # noqa: E501


        :return: The retries of this IntegrationCall.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this IntegrationCall.


        :param retries: The retries of this IntegrationCall.  # noqa: E501
        :type: int
        """

        self._retries = retries

    @property
    def last_call_time(self):
        """Gets the last_call_time of this IntegrationCall.  # noqa: E501


        :return: The last_call_time of this IntegrationCall.  # noqa: E501
        :rtype: datetime
        """
        return self._last_call_time

    @last_call_time.setter
    def last_call_time(self, last_call_time):
        """Sets the last_call_time of this IntegrationCall.


        :param last_call_time: The last_call_time of this IntegrationCall.  # noqa: E501
        :type: datetime
        """

        self._last_call_time = last_call_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IntegrationCall, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationCall):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.helper.json_converter import JsonConverter
from pdf4me.helper.pdf4me_exceptions import Pdf4meBackendException

# python version dependent import
try:
    from json import JSONDecoder
except ImportError:
    pass


class ResponseChecker(object):

    def check_response_for_errors(selfself, res):
        '''
        Checks document logs for error reports, in case an error is found a Pdf4meBackendException is thrown.
        :param res: content of response
        :type res: string
        :return: None
        '''

        jsonConverter = JsonConverter()

        if res is None:
            raise Pdf4meBackendException('Server Error')

        # check whether the res contains none, one or multiple documents
        one_doc = None
        multiple_docs = None
        docs = []

        try:
            one_doc = jsonConverter.load(res)['document']
        except KeyError:
            pass
        except ValueError:
            pass
        except TypeError:
            pass
        except JSONDecoder:
            pass

        try:
            multiple_docs = jsonConverter.load(res)['documents']
        except KeyError:
            pass
        except ValueError:
            pass
        except TypeError:
            pass
        except JSONDecoder:
            pass

        if one_doc is not None:
            docs = [one_doc]
        elif multiple_docs is not None:
            docs = multiple_docs
        # otw docs is empty

        # extract the logs
        doc_logs = []
        for i in range(len(docs)):
            doc_logs = doc_logs + docs[i]['doc_logs']

        # check all logs for errors
        for i in range(len(doc_logs)):
            current_doc_log = doc_logs[i]
            if (current_doc_log['doc_log_level'] == 3):
                raise Pdf4meBackendException(current_doc_log['message'])



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Notification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'get_notification': 'bool',
        'connection_id': 'str',
        'app_async_proc_type': 'str',
        'integrations': 'list[str]'
    }

    attribute_map = {
        'get_notification': 'getNotification',
        'connection_id': 'connectionId',
        'app_async_proc_type': 'appAsyncProcType',
        'integrations': 'integrations'
    }

    def __init__(self, get_notification=None, connection_id=None, app_async_proc_type=None, integrations=None):  # noqa: E501
        """Notification - a model defined in Swagger"""  # noqa: E501

        self._get_notification = None
        self._connection_id = None
        self._app_async_proc_type = None
        self._integrations = None
        self.discriminator = None

        if get_notification is not None:
            self.get_notification = get_notification
        if connection_id is not None:
            self.connection_id = connection_id
        if app_async_proc_type is not None:
            self.app_async_proc_type = app_async_proc_type
        if integrations is not None:
            self.integrations = integrations

    @property
    def get_notification(self):
        """Gets the get_notification of this Notification.  # noqa: E501

        Run execution in asynchronous way, get notified over Online WebHook  # noqa: E501

        :return: The get_notification of this Notification.  # noqa: E501
        :rtype: bool
        """
        return self._get_notification

    @get_notification.setter
    def get_notification(self, get_notification):
        """Sets the get_notification of this Notification.

        Run execution in asynchronous way, get notified over Online WebHook  # noqa: E501

        :param get_notification: The get_notification of this Notification.  # noqa: E501
        :type: bool
        """

        self._get_notification = get_notification

    @property
    def connection_id(self):
        """Gets the connection_id of this Notification.  # noqa: E501

        Will be used for Online WebHook  # noqa: E501

        :return: The connection_id of this Notification.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this Notification.

        Will be used for Online WebHook  # noqa: E501

        :param connection_id: The connection_id of this Notification.  # noqa: E501
        :type: str
        """

        self._connection_id = connection_id

    @property
    def app_async_proc_type(self):
        """Gets the app_async_proc_type of this Notification.  # noqa: E501


        :return: The app_async_proc_type of this Notification.  # noqa: E501
        :rtype: str
        """
        return self._app_async_proc_type

    @app_async_proc_type.setter
    def app_async_proc_type(self, app_async_proc_type):
        """Sets the app_async_proc_type of this Notification.


        :param app_async_proc_type: The app_async_proc_type of this Notification.  # noqa: E501
        :type: str
        """

        self._app_async_proc_type = app_async_proc_type

    @property
    def integrations(self):
        """Gets the integrations of this Notification.  # noqa: E501


        :return: The integrations of this Notification.  # noqa: E501
        :rtype: list[str]
        """
        return self._integrations

    @integrations.setter
    def integrations(self, integrations):
        """Sets the integrations of this Notification.


        :param integrations: The integrations of this Notification.  # noqa: E501
        :type: list[str]
        """

        self._integrations = integrations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Notification, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Notification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.action_flow import ActionFlow  # noqa: F401,E501
from pdf4me.model.execution_trigger import ExecutionTrigger  # noqa: F401,E501
from pdf4me.model.storage_folder import StorageFolder  # noqa: F401,E501


class JobConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_config_id': 'str',
        'enabled': 'bool',
        'active': 'bool',
        'creation_date': 'datetime',
        'mod_date': 'datetime',
        'name': 'str',
        'user_id': 'str',
        'tenant_id': 'str',
        'source_folder': 'StorageFolder',
        'execution_trigger': 'ExecutionTrigger',
        'action_flow': 'ActionFlow',
        'target_folder': 'StorageFolder'
    }

    attribute_map = {
        'job_config_id': 'jobConfigId',
        'enabled': 'enabled',
        'active': 'active',
        'creation_date': 'creationDate',
        'mod_date': 'modDate',
        'name': 'name',
        'user_id': 'userId',
        'tenant_id': 'tenantId',
        'source_folder': 'sourceFolder',
        'execution_trigger': 'executionTrigger',
        'action_flow': 'actionFlow',
        'target_folder': 'targetFolder'
    }

    def __init__(self, job_config_id=None, enabled=None, active=None, creation_date=None, mod_date=None, name=None, user_id=None, tenant_id=None, source_folder=None, execution_trigger=None, action_flow=None, target_folder=None):  # noqa: E501
        """JobConfig - a model defined in Swagger"""  # noqa: E501

        self._job_config_id = None
        self._enabled = None
        self._active = None
        self._creation_date = None
        self._mod_date = None
        self._name = None
        self._user_id = None
        self._tenant_id = None
        self._source_folder = None
        self._execution_trigger = None
        self._action_flow = None
        self._target_folder = None
        self.discriminator = None

        self.job_config_id = job_config_id
        self.enabled = enabled
        if active is not None:
            self.active = active
        if creation_date is not None:
            self.creation_date = creation_date
        if mod_date is not None:
            self.mod_date = mod_date
        self.name = name
        self.user_id = user_id
        self.tenant_id = tenant_id
        if source_folder is not None:
            self.source_folder = source_folder
        if execution_trigger is not None:
            self.execution_trigger = execution_trigger
        if action_flow is not None:
            self.action_flow = action_flow
        if target_folder is not None:
            self.target_folder = target_folder

    @property
    def job_config_id(self):
        """Gets the job_config_id of this JobConfig.  # noqa: E501


        :return: The job_config_id of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._job_config_id

    @job_config_id.setter
    def job_config_id(self, job_config_id):
        """Sets the job_config_id of this JobConfig.


        :param job_config_id: The job_config_id of this JobConfig.  # noqa: E501
        :type: str
        """
        if job_config_id is None:
            raise ValueError("Invalid value for `job_config_id`, must not be `None`")  # noqa: E501

        self._job_config_id = job_config_id

    @property
    def enabled(self):
        """Gets the enabled of this JobConfig.  # noqa: E501


        :return: The enabled of this JobConfig.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this JobConfig.


        :param enabled: The enabled of this JobConfig.  # noqa: E501
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def active(self):
        """Gets the active of this JobConfig.  # noqa: E501


        :return: The active of this JobConfig.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this JobConfig.


        :param active: The active of this JobConfig.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def creation_date(self):
        """Gets the creation_date of this JobConfig.  # noqa: E501


        :return: The creation_date of this JobConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this JobConfig.


        :param creation_date: The creation_date of this JobConfig.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def mod_date(self):
        """Gets the mod_date of this JobConfig.  # noqa: E501


        :return: The mod_date of this JobConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this JobConfig.


        :param mod_date: The mod_date of this JobConfig.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def name(self):
        """Gets the name of this JobConfig.  # noqa: E501


        :return: The name of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobConfig.


        :param name: The name of this JobConfig.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def user_id(self):
        """Gets the user_id of this JobConfig.  # noqa: E501


        :return: The user_id of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this JobConfig.


        :param user_id: The user_id of this JobConfig.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this JobConfig.  # noqa: E501


        :return: The tenant_id of this JobConfig.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this JobConfig.


        :param tenant_id: The tenant_id of this JobConfig.  # noqa: E501
        :type: str
        """
        if tenant_id is None:
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def source_folder(self):
        """Gets the source_folder of this JobConfig.  # noqa: E501


        :return: The source_folder of this JobConfig.  # noqa: E501
        :rtype: StorageFolder
        """
        return self._source_folder

    @source_folder.setter
    def source_folder(self, source_folder):
        """Sets the source_folder of this JobConfig.


        :param source_folder: The source_folder of this JobConfig.  # noqa: E501
        :type: StorageFolder
        """

        self._source_folder = source_folder

    @property
    def execution_trigger(self):
        """Gets the execution_trigger of this JobConfig.  # noqa: E501


        :return: The execution_trigger of this JobConfig.  # noqa: E501
        :rtype: ExecutionTrigger
        """
        return self._execution_trigger

    @execution_trigger.setter
    def execution_trigger(self, execution_trigger):
        """Sets the execution_trigger of this JobConfig.


        :param execution_trigger: The execution_trigger of this JobConfig.  # noqa: E501
        :type: ExecutionTrigger
        """

        self._execution_trigger = execution_trigger

    @property
    def action_flow(self):
        """Gets the action_flow of this JobConfig.  # noqa: E501


        :return: The action_flow of this JobConfig.  # noqa: E501
        :rtype: ActionFlow
        """
        return self._action_flow

    @action_flow.setter
    def action_flow(self, action_flow):
        """Sets the action_flow of this JobConfig.


        :param action_flow: The action_flow of this JobConfig.  # noqa: E501
        :type: ActionFlow
        """

        self._action_flow = action_flow

    @property
    def target_folder(self):
        """Gets the target_folder of this JobConfig.  # noqa: E501


        :return: The target_folder of this JobConfig.  # noqa: E501
        :rtype: StorageFolder
        """
        return self._target_folder

    @target_folder.setter
    def target_folder(self, target_folder):
        """Sets the target_folder of this JobConfig.


        :param target_folder: The target_folder of this JobConfig.  # noqa: E501
        :type: StorageFolder
        """

        self._target_folder = target_folder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
